@@ -285,7 +285,10 @@ ORDER BY
                 "type_resolution_method": type_resolution_method
             })
 
-        return sorted(res, key=lambda x: (x["exception"] if x["exception"] is not None else '', float('-inf') if x["cost"] is None else -x["cost"]))
+        if inputs.get("sort_cost", True):
+            return sorted(res, key=lambda x: (x["exception"] if x["exception"] is not None else '', float('-inf') if x["cost"] is None else -x["cost"]))
+        else:
+            return res
 
     def prepare_queries__old(self, connection: DBInterface, account_id: str, inputs: dict):
         # Important! Permission check by checking that the user can in insert into the application table. This is equivalent of checking if the user
